@@ -115,7 +115,7 @@ pub fn solve(input: &mut Input) -> Result<SignalValue, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let real_input = include_str!("day07_input.txt");
     test_part_one!(real_input => 3176);
