@@ -37,7 +37,7 @@ pub fn solve(input: &mut Input) -> Result<String, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let real_input = include_str!("day16_input.txt");
     test_part_one!(real_input => "11100110111101110".to_string());
